import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useEffect } from "react";
import cx from "classnames";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faClipboard, faCheck } from "@fortawesome/free-solid-svg-icons";
import { Button } from "../Button";
import styles from "./CopyButton.less";
export var CopyButton = function CopyButton(props) {
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      copied = _useState2[0],
      setCopied = _useState2[1];

  function fallback(text) {
    if (window.clipboardData && window.clipboardData.setData) {
      // IE specific code path to prevent textarea being shown while dialog is visible.
      return window.clipboardData.setData("Text", text);
    } else if (document.queryCommandSupported && document.queryCommandSupported("copy")) {
      var textarea = document.createElement("textarea");
      textarea.innerText = text;
      document.body.appendChild(textarea);
      textarea.select();

      try {
        setCopied(true);
        document.execCommand("copy");
      } catch (err) {
        console.err(err);
        return false;
      } finally {
        document.body.removeChild(textarea);
      }
    }
  }

  var copyValue = function copyValue() {
    if (navigator.clipboard) {
      navigator.clipboard.writeText(props.value);
      setCopied(true);
    } else {
      fallback(props.value);
    }
  };

  useEffect(function () {
    var iconTimer = setTimeout(function () {
      setCopied(false);
    }, 500);
    return function () {
      clearTimeout(iconTimer);
    };
  }, [copied]);
  return /*#__PURE__*/React.createElement(Button, {
    className: cx(styles.CopyButton, props.className),
    onClick: copyValue,
    kind: props.kind,
    type: props.type,
    size: props.size,
    title: props.children ? "Copy ".concat(props.children) : "Copy ".concat(props.value)
  }, copied ? /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    className: styles.CheckIcon,
    icon: faCheck
  }) : /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: faClipboard
  }), props.children ? props.children : props.value);
};