import React, { useRef } from "react";
import cx from "classnames";
import Flatpickr from "react-flatpickr";
import confirmDatePlugin from "flatpickr/dist/plugins/confirmDate/confirmDate";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faCalendar } from "@fortawesome/free-solid-svg-icons";
import { Button } from "../Button";
import { FieldDescription } from "../FieldDescription";
import { FieldLabel } from "../FieldLabel";
import styles from "./FieldTypeDate.less";
export var FieldTypeDate = /*#__PURE__*/React.memo(function FieldTypeDate(props) {
  // console.log("FieldTypeDate:render");
  var ref = useRef();

  var openCalendar = function openCalendar() {
    setTimeout(function () {
      return ref.current.flatpickr.open();
    }, 0);
  };

  var onChange = function onChange(date) {
    if (props.onChange) {
      props.onChange(date[0], props.name, props.datatype);
    }
  };

  return /*#__PURE__*/React.createElement("label", {
    className: cx(styles.FieldTypeDate, props.className)
  }, /*#__PURE__*/React.createElement(FieldLabel, {
    label: props.label,
    required: props.required,
    tooltip: props.tooltip,
    tag: props.tag
  }), /*#__PURE__*/React.createElement("span", {
    className: styles.FieldTypeDateInput
  }, props.datatype === "datetime" ? /*#__PURE__*/React.createElement(Flatpickr, {
    ref: ref,
    "data-enable-time": true,
    className: cx(styles.DatePicker, props.className),
    name: props.name,
    value: props.value,
    onChange: onChange,
    options: {
      altFormat: "F j Y, at h:i K",
      altInput: true,
      plugins: [new confirmDatePlugin({
        confirmIcon: "<i class='fa fa-check'></i>",
        confirmText: "CONFIRM ",
        showAlways: false,
        theme: "light"
      })]
    }
  }) : /*#__PURE__*/React.createElement(Flatpickr, {
    ref: ref,
    className: cx(styles.DatePicker, props.className),
    name: props.name,
    value: props.value,
    onChange: onChange
  }), /*#__PURE__*/React.createElement(Button, {
    onClick: openCalendar,
    className: styles.Icon
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: faCalendar
  }))), /*#__PURE__*/React.createElement(FieldDescription, {
    description: props.description
  }));
});