import React, { Fragment } from "react";
import showdown from "showdown";
import { BasicEditor } from "./Editors/Basic.js"; // Covers both WYSIWYGBasic & WYSIWYGAdvanced field types

import { InlineEditor } from "./Editors/Inline.js";
import { MarkdownEditor } from "./Editors/Markdown.js";
import { HtmlEditor } from "./Editors/Html.js";
export var convert = new showdown.Converter({
  noHeaderId: true,
  tables: true,
  strikethrough: true // backslashEscapesHTMLTags: true

});
/**
 * Handle recieving and emitting markdown vs html
 * A markdown field should *always* emit markdown syntax
 * Because the fields editor can be swapped ad-hoc this component has 
 * to handle sending down the expected editor syntax but emitting the correct
 * syntax for a datatype on change.
 */

export var Converter = /*#__PURE__*/React.memo(function Converter(props) {
  // NOTE: emit formated changes to listeners
  var onChange = function onChange(val) {
    if (val === "<p></p>") {
      val = "";
    }

    if (props.datatype === "markdown") {
      // NOTE: If a markdown field but being viewed in a non-markdown editor
      // convert back to markdown before emitting change. This ensures markdown syntax
      // is saved to the API
      if (props.editor !== "markdown") {
        val = convert.makeMarkdown(val);
      }
    } else {
      val = convert.makeHtml(val);
    }

    props.onChange(val, props.name, props.datatype);
  }; // NOTE: Based on selected editor convert content on the way into the component
  // if markdown datatype but in a different editor mode convert to html
  // works in tandem with formating during onChange function


  var content = props.value;

  if (props.datatype === "markdown" && props.editor !== "markdown") {
    content = convert.makeHtml(props.value);
  }

  if (props.datatype !== "markdown" && props.editor === "markdown") {
    content = convert.makeMarkdown(props.value);
  }

  return /*#__PURE__*/React.createElement(Fragment, null, props.editor === "wysiwyg_basic" && /*#__PURE__*/React.createElement(BasicEditor, {
    value: content,
    version: props.version,
    mediaBrowser: props.mediaBrowser,
    onChange: onChange
  }), props.editor === "article_writer" && /*#__PURE__*/React.createElement(InlineEditor, {
    value: content,
    version: props.version,
    mediaBrowser: props.mediaBrowser,
    onChange: onChange
  }), props.editor === "markdown" && /*#__PURE__*/React.createElement(MarkdownEditor, {
    value: content,
    version: props.version,
    onChange: onChange
  }), props.editor === "html" && /*#__PURE__*/React.createElement(HtmlEditor, {
    value: content,
    version: props.version,
    onChange: onChange
  }));
});