import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useEffect, useRef, useState, useMemo } from "react"; // import { HtmlEditor } from "@aeaton/react-prosemirror";

import { HtmlEditor } from "./react-prosemirror/HtmlEditor"; // import { MenuBar } from "@aeaton/react-prosemirror";

import { MenuBar } from "./react-prosemirror/MenuBar";
import { LinkModal } from "./LinkModal";
import { EmbedModal } from "./EmbedModal";
import { schema } from "./react-prosemirror-schema";
import { plugins } from "./react-prosemirror-plugins";
import { menu } from "./react-prosemirror-menu";
import { ImageResizeView } from "./prosemirror-views/ImageResizeView";
import { IframeResizeView } from "./prosemirror-views/IframeResizeView";
import { VideoResizeView } from "./prosemirror-views/VideoResizeView";
import styles from "./Basic.less";
export function BasicEditor(props) {
  var ref = useRef();

  var _useState = useState({
    showLinkModal: false,
    showEmbedModal: false,
    showEmbedModalOptions: {}
  }),
      _useState2 = _slicedToArray(_useState, 2),
      modals = _useState2[0],
      setModals = _useState2[1]; // only recreate options, which cause prosemirror update,
  // when the version changes. Otherwise prosemirror manages
  // it's own internal document model


  var options = useMemo(function () {
    return {
      plugins: plugins,
      schema: schema
    };
  }, [props.version]);

  var onModalOpen = function onModalOpen(name, options) {
    // NOTE: We match a queryselctor with the prosemirror dom to handle multiple editors in a single view.
    if (ref.current && ref.current.querySelector && ref.current.querySelector(".ProseMirror") == options.view.dom) {
      var _objectSpread2;

      setModals(_objectSpread(_objectSpread({}, modals), {}, (_objectSpread2 = {}, _defineProperty(_objectSpread2, name, true), _defineProperty(_objectSpread2, "".concat(name, "Options"), options), _objectSpread2)));
    }
  };

  var onModalClose = function onModalClose(name) {
    setModals(_objectSpread(_objectSpread({}, modals), {}, _defineProperty({}, name, false)));
  };

  useEffect(function () {
    zesty.on("PROSEMIRROR_DIALOG_OPEN", onModalOpen);
    zesty.on("PROSEMIRROR_DIALOG_CLOSE", onModalClose);
    return function () {
      zesty.off("PROSEMIRROR_DIALOG_OPEN", onModalOpen);
      zesty.off("PROSEMIRROR_DIALOG_CLOSE", onModalClose);
    };
  }, [ref]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles.BasicEditor
  }, /*#__PURE__*/React.createElement(HtmlEditor, {
    options: options,
    value: props.value,
    version: props.version,
    modals: modals // provided to editor so it can make render choice
    ,
    onChange: props.onChange,
    render: function render(_ref) {
      var editor = _ref.editor,
          view = _ref.view;
      return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(LinkModal, {
        view: view,
        open: modals.showLinkModal
      }), /*#__PURE__*/React.createElement(EmbedModal, {
        open: modals.showEmbedModal,
        options: modals.showEmbedModalOptions,
        view: view
      }), /*#__PURE__*/React.createElement(MenuBar, {
        menu: menu({
          mediaBrowser: props.mediaBrowser
        }),
        view: view
      }), /*#__PURE__*/React.createElement("div", {
        ref: ref
      }, editor));
    },
    nodeViews: {
      image: function image(node, view, getPos) {
        return new ImageResizeView(node, view, getPos);
      },
      iframe: function iframe(node, view, getPos) {
        return new IframeResizeView(node, view, getPos);
      },
      video: function video(node, view, getPos) {
        return new VideoResizeView(node, view, getPos);
      }
    }
  }));
}