import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import { attributes, getElementAttrs } from "./nodes";
var link = {
  attrs: _objectSpread(_objectSpread({}, attributes()), {}, {
    href: {},
    target: {
      "default": null
    }
  }),
  inclusive: false,
  parseDOM: [{
    tag: "a[href]",
    getAttrs: function getAttrs(dom) {
      return getElementAttrs(dom);
    }
  }],
  toDOM: function toDOM(node) {
    return ["a", node.attrs, 0];
  }
}; // :: MarkSpec An emphasis mark. Rendered as an `<em>` element.
// Has parse rules that also match `<i>` and `font-style: italic`.

var em = {
  parseDOM: [{
    tag: "i"
  }, {
    tag: "em"
  }, {
    style: "font-style=italic"
  }],
  toDOM: function toDOM() {
    return ["em", 0];
  }
}; // :: MarkSpec A strong mark. Rendered as `<strong>`, parse rules
// also match `<b>` and `font-weight: bold`.

var strong = {
  parseDOM: [{
    tag: "strong"
  }, // This works around a Google Docs misbehavior where
  // pasted content will be inexplicably wrapped in `<b>`
  // tags with a font-weight normal.
  {
    tag: "b",
    getAttrs: function getAttrs(node) {
      return node.style.fontWeight != "normal" && null;
    }
  }, {
    style: "font-weight",
    getAttrs: function getAttrs(value) {
      return /^(bold(er)?|[5-9]\d{2,})$/.test(value) && null;
    }
  }],
  toDOM: function toDOM() {
    return ["strong", 0];
  }
}; // :: MarkSpec Code font mark. Represented as a `<code>` element.

var code = {
  parseDOM: [{
    tag: "code"
  }],
  toDOM: function toDOM() {
    return ["code", 0];
  }
};
var subscript = {
  excludes: "superscript",
  parseDOM: [{
    tag: "sub"
  }, {
    style: "vertical-align=sub"
  }],
  toDOM: function toDOM() {
    return ["sub"];
  }
};
var superscript = {
  excludes: "subscript",
  parseDOM: [{
    tag: "sup"
  }, {
    style: "vertical-align=super"
  }],
  toDOM: function toDOM() {
    return ["sup"];
  }
};
var strikethrough = {
  parseDOM: [{
    tag: "strike"
  }, {
    style: "text-decoration=line-through"
  }, {
    style: "text-decoration-line=line-through"
  }],
  toDOM: function toDOM() {
    return ["del", {
      style: "text-decoration-line:line-through"
    }];
  }
};
var underline = {
  parseDOM: [{
    tag: "u"
  }, {
    style: "text-decoration=underline"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "text-decoration:underline"
    }];
  }
};
var indent = {
  parseDOM: [{
    style: "padding-left=30px"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "padding-left:30px"
    }];
  }
};
var alignLeft = {
  parseDOM: [{
    style: "text-align=left"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "display:block;text-align:left"
    }];
  }
};
var alignRight = {
  parseDOM: [{
    style: "text-align=right"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "display:block;text-align:right"
    }];
  }
};
var alignCenter = {
  parseDOM: [{
    style: "text-align=center"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "display:block;text-align:center"
    }];
  }
};
var alignJustify = {
  parseDOM: [{
    style: "text-align=justify"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "display:block;text-align:justify"
    }];
  }
};
var floatLeft = {
  parseDOM: [{
    style: "float=left"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "display:block;float:left"
    }];
  }
};
var floatRight = {
  parseDOM: [{
    style: "float=right"
  }],
  toDOM: function toDOM() {
    return ["span", {
      style: "display:block;float:right"
    }];
  }
};
export default {
  link: link,
  em: em,
  strong: strong,
  code: code,
  subscript: subscript,
  superscript: superscript,
  strikethrough: strikethrough,
  underline: underline,
  indent: indent,
  alignLeft: alignLeft,
  alignRight: alignRight,
  alignCenter: alignCenter,
  alignJustify: alignJustify,
  floatLeft: floatLeft,
  floatRight: floatRight
};