import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useCallback, useMemo } from "react";
import debounce from "lodash/debounce";
import { DOMParser, DOMSerializer } from "prosemirror-model";
import Editor from "./Editor";

var parser = function parser(schema) {
  var parser = DOMParser.fromSchema(schema);
  return function (content) {
    var container = document.createElement("article");
    container.innerHTML = content;
    return parser.parse(container);
  };
};

var serializer = function serializer(schema) {
  var serializer = DOMSerializer.fromSchema(schema);
  return function (doc) {
    var container = document.createElement("article");
    container.appendChild(serializer.serializeFragment(doc.content));
    return container.innerHTML;
  };
};

export function HtmlEditor(props) {
  // recreate parse/seralize if options props changes
  var parse = useCallback(parser(props.options.schema), [props.options]);
  var serialize = useCallback(serializer(props.options.schema), [props.options]);
  var onChange = useCallback(function (doc) {
    return props.onChange(serialize(doc));
  }, [serialize]); // recreate memoized options if parse changes

  var opts = useMemo(function () {
    var newOpts = _objectSpread({}, props.options);

    newOpts.doc = parse(props.value);
    return newOpts;
  }, [parse]);
  return /*#__PURE__*/React.createElement(Editor, {
    onChange: onChange,
    options: opts,
    autoFocus: props.autoFocus,
    attributes: props.attributes,
    render: props.render,
    version: props.version,
    modals: props.modals,
    nodeViews: props.nodeViews
  });
}