import _extends from "@babel/runtime/helpers/extends";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useEffect } from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faExclamationTriangle } from "@fortawesome/free-solid-svg-icons";
import { Tag } from "../Tag";
import { Loader } from "../Loader";
import { Select, Option } from "../Select";
import { FieldLabel } from "../FieldLabel";
import { FieldDescription } from "../FieldDescription";
import styles from "./FieldTypeOneToMany.less";
export var FieldTypeOneToMany = /*#__PURE__*/React.memo(function FieldTypeOneToMany(props) {
  var _props$maxLength, _props$value$length, _props$value;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      loaded = _useState2[0],
      setLoaded = _useState2[1]; // Used to ensure we only load data once


  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      loading = _useState4[0],
      setLoading = _useState4[1];

  var _useState5 = useState( // split string of zuids and trim any whitespace
  props.value ? props.value.split(",").map(function (v) {
    return v.trim();
  }) : []),
      _useState6 = _slicedToArray(_useState5, 2),
      selectedItems = _useState6[0],
      setSelectedItems = _useState6[1];

  var maxLength = (_props$maxLength = props.maxLength) !== null && _props$maxLength !== void 0 ? _props$maxLength : 255;
  var valueLength = (_props$value$length = (_props$value = props.value) === null || _props$value === void 0 ? void 0 : _props$value.length) !== null && _props$value$length !== void 0 ? _props$value$length : 0;

  var loadItems = function loadItems() {
    setLoading(true);
    props.onOpen().then(function () {
      setLoading(false);
      setLoaded(true);
    });
  }; // On initial render if we have selected items then load them from the API


  useEffect(function () {
    if (selectedItems.length) {
      loadItems();
    }
  }, []);
  /**
   * Remove selected zuid from array and broadcast change
   * @param {String} zuid
   */

  var onRemove = function onRemove(zuid) {
    // Exclude the removed item from our `selectedItems` array
    var filteredItems = selectedItems.filter(function (item) {
      return item !== zuid;
    });
    setSelectedItems(filteredItems);

    if (props.onChange) {
      props.onChange( // send a csv string to update store
      filteredItems.join(","), props.name, props.datatype);
    }
  };
  /**
   *
   * @param {String} value
   */


  var onSelect = function onSelect(value) {
    var option = props.options.find(function (option) {
      return option.value === value;
    });

    if (option && option.value !== "0") {
      var items = [option.value].concat(_toConsumableArray(selectedItems));
      setSelectedItems(items);

      if (props.onChange) {
        props.onChange( // send a csv string to update store
        items.join(","), props.name, props.datatype);
      }
    } else {
      console.error("FieldTypeOneToMany:onSelect - Unknown option selected (".concat(value, ")"));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: props.className
  }, /*#__PURE__*/React.createElement("label", {
    htmlFor: props.name
  }, /*#__PURE__*/React.createElement(FieldLabel, {
    label: props.label,
    required: props.required,
    tag: props.tag,
    tooltip: props.tooltip,
    maxLength: maxLength,
    valueLength: valueLength
  })), /*#__PURE__*/React.createElement("section", {
    className: styles.OneToMany
  }, /*#__PURE__*/React.createElement(Select, {
    className: styles.Select,
    name: props.name,
    value: "0" // By providing a 0 value we pre-select our "empty" option
    ,
    onSelect: onSelect,
    onClick: function onClick() {
      if (!loaded && props.onOpen) {
        loadItems();
      }
    },
    error: valueLength > maxLength
  }, /*#__PURE__*/React.createElement(Option, {
    value: "0",
    text: "\u2014 Select Option \u2014"
  }), loading && /*#__PURE__*/React.createElement(Loader, null), props.options.map(function (opt, i) {
    return /*#__PURE__*/React.createElement(Option, _extends({
      key: i
    }, opt));
  })), /*#__PURE__*/React.createElement("article", {
    className: styles.Tags
  }, selectedItems.length ? selectedItems.map(function (ZUID, i) {
    var item = props.options.find(function (option) {
      return option.value === ZUID;
    });
    return item ? /*#__PURE__*/React.createElement(Tag, {
      key: i,
      onRemove: onRemove,
      value: item.value
    }, item.component || item.text || item.filterValue) : /*#__PURE__*/React.createElement(Tag, {
      key: i,
      onRemove: onRemove,
      value: ZUID,
      error: true
    }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
      icon: faExclamationTriangle
    }), "\xA0", ZUID, " is not an item of the related model");
  }) : /*#__PURE__*/React.createElement("p", null, "Select tags to associate them with your item."))), valueLength > maxLength && /*#__PURE__*/React.createElement("span", {
    className: styles.ErrorDescription
  }, "Your input is over the default limit"), /*#__PURE__*/React.createElement(FieldDescription, {
    description: props.description
  }));
});