import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useEffect, useLayoutEffect, useRef } from "react";
import cx from "classnames";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faTimes } from "@fortawesome/free-solid-svg-icons";
import { Button } from "../Button";
import styles from "./Modal.less";
export var Modal = /*#__PURE__*/React.memo(function Modal(props) {
  var _useState = useState(Boolean(props.open)),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var styleLocal = props.type === "local" ? styles.Local : null;
  var styleGlobal = props.type === "global" ? styles.Global : null;
  var styleOpen = open ? styles.Open : null;

  var onClose = function onClose(evt) {
    setOpen(false);

    if (props.onClose) {
      props.onClose(evt);
    }
  };

  var onEsc = function onEsc(evt) {
    if (evt.key === "Escape" || evt.keyCode == 27) {
      onClose(evt);
    }
  };

  useEffect(function () {
    window.addEventListener("keyup", onEsc);
    return function () {
      window.removeEventListener("keyup", onEsc);
    };
  }, []); // Allow consumer to update internal open state

  useEffect(function () {
    return setOpen(Boolean(props.open));
  }, [props.open]);
  var modalRef = useRef(null);
  useLayoutEffect(function () {
    if (modalRef.current) {
      var modalPosition = modalRef.current.getBoundingClientRect();

      if (modalPosition.left < 0) {
        // Modals total width(including padding) + negative left offset - left & right padding - additional 8px for spacing
        var width = modalPosition.width + modalPosition.left - 64 - 8;
        modalRef.current.style.minWidth = "".concat(width, "px");
      }
    }
  }, [open]);
  return /*#__PURE__*/React.createElement("div", {
    className: cx(styles.ModalAligner, styleLocal, styleGlobal, styleOpen)
  }, /*#__PURE__*/React.createElement("article", {
    ref: modalRef,
    className: cx(styles.Modal, styleLocal, styleGlobal, props.className)
  }, /*#__PURE__*/React.createElement(Button, {
    className: styles.Close,
    onClick: onClose
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: faTimes
  })), props.children));
});
export var ModalHeader = /*#__PURE__*/React.memo(function ModalHeader(props) {
  return /*#__PURE__*/React.createElement("header", {
    className: cx(styles.ModalHeader, props.className)
  }, props.children);
});
export var ModalContent = /*#__PURE__*/React.memo(function ModalContent(props) {
  return /*#__PURE__*/React.createElement("main", _extends({}, props, {
    className: cx(styles.ModalContent, props.className)
  }), props.children);
});
export var ModalFooter = /*#__PURE__*/React.memo(function ModalFooter(props) {
  return /*#__PURE__*/React.createElement("footer", {
    className: cx(styles.ModalFooter, props.className)
  }, props.children);
});